#! /usr/bin/env python

#     Copyright (C) 2002 Stas Z  <stas@linux.isbeter.nl>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; see the file COPYING.  If not, write to
# the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
#

RCFILE = 0

import os,sys,random
import pygame
from pygame.constants import *
from utils import load_image,load_sound,MyError

class Img:
    pass
class Snd:
    pass


class Game(Img,Snd):
    """  memory.py - part of childsplay.py, a suite of educational games for
  young children.
  This is still very alpha, and will probably don't work"""

    def __init__(self,screen,backgr,rc_dic,basepath,libdir):
        self.screen = screen
        self.backgr = backgr
        self.rc_dic = rc_dic
        self.clock = pygame.time.Clock()
        self.eventget = pygame.event.get
        self.basedir  = basepath
        self.libdir = libdir
        self.selection = []
        self.selected = []
        self.score = 0
        self.gamelevels = [(2,3,167),(2,4,90),(3,4,90)]
        self.gameitems = [None]
        self.setup()
    
        
    def setup(self):
        file = os.path.join(self.basedir,'Data','dealcard1.wav')
        Snd.dealing = load_sound(file) 
        file = os.path.join(self.basedir,'Data','wahoo.wav')
        Snd.wahoo = load_sound(file)
        #file = os.path.join(self.basedir,'Data','level_clear.wav')
        #Snd.endlevel = load_sound(file) 
       
    def load_cards(self,num):
        """  Load cards and shuffle them. Images are stored in a list as pygame
        image objects."""
        name = os.path.join(self.libdir,'MemoryData')
        files = os.listdir(name)
        map(files.remove,filter(os.path.isdir,files)) # filter out directorys
        if files >= num:
            random.shuffle(files)
            files = files[:num]
        else:
            info =' To little pictures in '+name
            MyError.name = __name__
            raise MyError,info
        dirlist = map(os.path.join,[name]*len(files),files)
        img_obj_list = map(load_image,dirlist)
        img_obj_list = img_obj_list * 2 # every picture must be double
        random.shuffle(img_obj_list)
    
        return img_obj_list
    
    def helptitle(self):
        return _("Memory")
    
    def help(self):
        text = [_("The aim of the game:"),
        _("Classic memory game where you have to find pairs of cards."),
        " ",
        _("Difficulty : 2-5 years"),
        " ",
        _("Number of levels : 3")]

        return text 
    
    def start(self,l,spam):
        """Turn the cards and find pairs"""
        self.stop = 0
        #levels = [(2,3,167),(2,4,90),(3,4,90)]
        #r, c ,offset = levels[i-1]
        r, c ,offset = l
        self.deal_cards(r,c,offset)
    
    def deal_cards(self,rows,cols,offset):
        """ Deal the cards and store them in a reference matrix. Display
        the closed cards. The matrix is a dictionary with tuples as keys
         key = tuple(rect), value = image object."""
        
        obj_items = self.load_cards((rows*cols)/2)
        self.matrix = {}
        file = os.path.join(self.basedir,'Data','cardback.png')
        Img.cback = load_image(file)
        
        
        for y in range(rows):
            for x in range(cols):
                obj = obj_items.pop()
                r = self.screen.blit(Img.cback,(offset + x*155,15 + y*155))
                self.matrix[tuple(r)] = obj
                pygame.display.update(r)
                Snd.dealing.play()
                pygame.time.wait(300)
        pyrect = pygame.Rect
        self.matrixrects = map(pyrect,self.matrix.keys())

    def loop(self,events):
        self.score = 0
        for event in events:
            if event.type is MOUSEBUTTONDOWN:
                self.on_select_activate()
        return self.stop,self.score
        
    def on_select_activate(self):
        pos = pygame.Rect(pygame.mouse.get_pos() + (4,4))
        selitem = None
        
        for rec in self.matrixrects:
            if rec.contains(pos):
                selitem = tuple(rec)
                break
        
        if not selitem: # Mouse outside any card
            return
        if not self.selection: # First card select
            self.selection = selitem
            self.turn_card(selitem)
            return
        if self.selection is selitem: # card is already selected
            return
        else:
            self.turn_card(selitem)
            if self.matrix[selitem] is self.matrix[self.selection]\
                and selitem != self.selection:
                
                #print 'objecten zijn gelijk'
                Snd.wahoo.play()
                self.score = 1
                pygame.time.wait(1000)
                
                del self.matrix[selitem]
                self.matrixrects.remove(pygame.Rect(selitem))
                r = self.screen.blit(self.backgr,selitem,selitem)
                del self.matrix[self.selection]
                self.matrixrects.remove(pygame.Rect(self.selection))
                rr = self.screen.blit(self.backgr,self.selection,self.selection)
                pygame.display.update((r,rr))
                self.selection = None
                if not self.matrixrects: # no more cards left
                    self.score = 100
                    self.stop = -1 # level is over
                                        
            else:
                #print 'objecten zijn ongelijk'
                #self.score = -1
                pygame.time.wait(1000)
                
                self.turn_card(selitem,Img.cback)
                self.turn_card(self.selection,Img.cback)
                self.selection = None
        
        return
    
    def turn_card(self,rect,obj=None):
        if not obj:
            obj = self.matrix[rect]
        self.screen.blit(obj,rect)
        pygame.display.update(rect)
        return


