"""
     Copyright (C) 2002-2003 Stas Z. <stas@linux.isbeter.nl>

 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2, or (at your option)
 any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; see the file COPYING.  If not, write to
 the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.

 Childsplay - A suite of educational games for young children.

  This is beta software, please send bugs and/or comments to
  childsplay@users.sourceforge.net"""


import pygame,os,sys
from pygame.constants import SWSURFACE,FULLSCREEN,QUIT,KEYDOWN,K_ESCAPE,MOUSEBUTTONDOWN
pygame.init()
scr = pygame.display.set_mode((800,600),SWSURFACE|FULLSCREEN)

from threading import Thread
from utils import trace_error,load_image,load_sound,Blink,load_music

basedir = os.path.dirname(sys.argv[0])

def splash():
    """Display a splash screen at startup.
      This runs in a seperate thread and ends when the user hits 'start',
      or at the timeout"""
    global load_rect
    T = 4000
    try:
        snd = load_sound(os.path.join(basedir,'Data','cows.wav'))
        snd.play(-1)
    except pygame.error,info:
        print >> sys.stderr,info
    try:
        cow = load_image(os.path.join(basedir,'Data','cowsplash.png'))
        load = load_image(os.path.join(basedir,'Data','cowsplash-load.png'))
        pygame.display.update((scr.blit(cow,(300,100)),scr.blit(load,(40,20))))
        load_rect = load.get_rect().move(40,20)
    except pygame.error:
        trace_error()
        T = 1
    # Keep it alive
    pygame.time.wait(T)
    try:
        snd.stop()
    except:
        pass
    
        
def start_buttons():
    """ Blit the buttons when the cow stops 'moowhing'. This should be called
     when CP is ready to roll.
     Returns the choosen button name."""
     
    thread.join()# wait until the cow thread is finished
    pygame.display.update(scr.fill((0,0,0),load_rect))
    obj_list = [Blink(load_image(os.path.join(basedir,'Data','cowsplash-start.png')),\
                        load_image(os.path.join(basedir,'Data','cowsplash-start-h.png')),(70,100),'start'),\
                Blink(load_image(os.path.join(basedir,'Data','cowsplash-about.png')),\
                    load_image(os.path.join(basedir,'Data','cowsplash-about-h.png')),(100,380),'about'),\
                Blink(load_image(os.path.join(basedir,'Data','cowsplash-quit.png')),\
                    load_image(os.path.join(basedir,'Data','cowsplash-quit-h.png')),(100,440),'quit')]
    snd = load_music(os.path.join(basedir,'Data','music1.ogg')) 
    snd.play(2)   
    clock = pygame.time.Clock()
    stop = 0
    timer = 0
    end = 52
    while timer < end:# let the music play and end this
        clock.tick(4)
        timer += 1
        
        pygame.event.pump()
        events = pygame.event.get()
        r = []
        for obj in obj_list:
            im,rec,data = obj.update()# data is not used here
            r.append((scr.blit(im,rec)))
        pygame.display.update(r)
        
        for event in events:
            if event.type is QUIT:
                timer = end
            elif event.type is KEYDOWN and event.key is K_ESCAPE:
                timer = end
            if event.type is MOUSEBUTTONDOWN and obj.DATA:
                snd.stop()
                return obj.DATA
    snd.stop()
    return "start" # default choice when the time out is reached
    
thread = Thread(target=splash)
thread.start()

pygame.time.wait(1)

    

